package com.zjsgfa.project.zjsgfa.service;

import java.util.List;
import com.zjsgfa.project.zjsgfa.domain.SjTgTgz;

/**
 * 设计信息-套管柱数据Service接口
 * 
 * @author ruoyi
 * @date 2025-07-17
 */
public interface ISjTgTgzService 
{
    /**
     * 查询设计信息-套管柱数据
     * 
     * @param id 设计信息-套管柱数据主键
     * @return 设计信息-套管柱数据
     */
    public SjTgTgz selectSjTgTgzById(Long id);

    /**
     * 查询设计信息-套管柱数据列表
     * 
     * @param sjTgTgz 设计信息-套管柱数据
     * @return 设计信息-套管柱数据集合
     */
    public List<SjTgTgz> selectSjTgTgzList(SjTgTgz sjTgTgz);

    /**
     * 新增设计信息-套管柱数据
     * 
     * @param sjTgTgz 设计信息-套管柱数据
     * @return 结果
     */
    public int insertSjTgTgz(SjTgTgz sjTgTgz);

    /**
     * 修改设计信息-套管柱数据
     * 
     * @param sjTgTgz 设计信息-套管柱数据
     * @return 结果
     */
    public int updateSjTgTgz(SjTgTgz sjTgTgz);

    /**
     * 批量删除设计信息-套管柱数据
     * 
     * @param ids 需要删除的设计信息-套管柱数据主键集合
     * @return 结果
     */
    public int deleteSjTgTgzByIds(Long[] ids);

    /**
     * 删除设计信息-套管柱数据信息
     * 
     * @param id 设计信息-套管柱数据主键
     * @return 结果
     */
    public int deleteSjTgTgzById(Long id);
}
